======================
miniBlog documentation
======================

miniBlog is a reusable Django application for managing a simple blog.

----

:Home: https://www.pascalpepe.com/en/projects/django-miniblog/
:Documentation: https://pascalpepe.gitlab.io/django-miniblog
:Source code: https://gitlab.com/pascalpepe/django-miniblog
:Issue tracker: https://gitlab.com/pascalpepe/django-miniblog/issues

.. note::

   This project is still in its initial development stage. Anything may change
   at any time.

----

Contents
========

.. toctree::
   :maxdepth: 2

   getting-started
   references/index
   releases/index
   license
